Welcome to ClientVPS Mirrors

Help for package ggplotgui
Title: Create Ggplots via a Graphical User Interface
Version: 1.0.0
Description: Easily explore data by creating ggplots through a (shiny-)GUI. R-code to recreate graph provided.
Depends: R (≥ 3.3.2)
Imports: plotly, shiny, ggplot2, stringr, readr, haven, readxl, RColorBrewer
License: GPL-3
BugReports: https://github.com/gertstulp/ggplotgui/issues
URL: https://github.com/gertstulp/ggplotgui/
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2017-07-07 16:24:50 UTC; gert
Author: Gert Stulp [aut, cre]
Maintainer: Gert Stulp <g.stulp@rug.nl>
Repository: CRAN
Date/Publication: 2017-07-08 03:25:44 UTC

Creating a graphical user interface for creating ggplot-graphs.

Description

Creating a graphical user interface for creating ggplot-graphs.

Usage

ggplot_shiny(dataset = NA)

Arguments

dataset

A dataset (optional).

Value

A GUI for visualizing data from dataset.

Examples

#ggplot_shiny()
#ggplot_shiny(mpg)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.